@@ -646,14 +646,11 @@ class Minion(object):
             except TypeError as exc:
                 trb = traceback.format_exc()
                 aspec = _getargs(minion_instance.functions[data['fun']])
-                log.warning(('TypeError encountered executing {0}. See debug '
-                             'log for more info.  Possibly a missing '
-                             'arguments issue:  {1}').format(function_name,
+                log.warning(('TypeError encountered executing {0}: {1}. See '
+                             'debug log for more info.  Possibly a missing '
+                             'arguments issue:  {2}').format(function_name,
+                                                             exc,
                                                              aspec))
-                msg = 'Missing arguments executing "{0}": {1}'.format(
-                    function_name, aspec
-                )
-                log.warning(msg)
                 log.debug(
                     'TypeError intercepted: {0}\n{1}'.format(exc, trb),
                     exc_info=True
@@ -987,9 +984,10 @@ class Minion(object):
 
         # Make sure to gracefully handle CTRL_LOGOFF_EVENT
         salt.utils.enable_ctrl_logoff_handler()
-        
+
         # On first startup execute a state run if configured to do so
         self._state_run()
+        time.sleep(.5)
 
         loop_interval = int(self.opts['loop_interval'])
         while True:
