@@ -19,15 +19,12 @@ import salt.utils
 # Tested on OpenBSD 5.0
 BSD = ('OpenBSD', 'FreeBSD')
 
-# Known not to work
-BAD = ('Windows',)
-
 
 def __virtual__():
     '''
     Most everything has the ability to support at(1)
     '''
-    if __grains__['os'] in BAD or not salt.utils.which('at'):
+    if salt.utils.is_windows() or not salt.utils.which('at'):
         return False
     return 'at'
 
