@@ -158,6 +158,7 @@ def _render_cmd(cmd, cwd, template):
 
 def _run(cmd,
          cwd=None,
+         stdin=None,
          stdout=subprocess.PIPE,
          stderr=subprocess.PIPE,
          quiet=False,
@@ -263,7 +264,7 @@ def _run(cmd,
             msg = 'Environment could not be retrieved for User \'{0}\''.format(runas)
             raise CommandExecutionError(msg)
 
-    if not quiet:
+    if not salt.utils.is_true(quiet):
         # Put the most common case first
         log.info(
             'Executing command {0!r} {1}in directory {2!r}'.format(
@@ -285,6 +286,7 @@ def _run(cmd,
     kwargs = {'cwd': cwd,
               'shell': True,
               'env': run_env,
+              'stdin': str(stdin) if stdin is not None else stdin,
               'stdout': stdout,
               'stderr': stderr}
 
@@ -340,6 +342,7 @@ def _run(cmd,
 
 def _run_quiet(cmd,
                cwd=None,
+               stdin=None,
                runas=None,
                shell=DEFAULT_SHELL,
                env=(),
@@ -352,6 +355,7 @@ def _run_quiet(cmd,
     return _run(cmd,
                 runas=runas,
                 cwd=cwd,
+                stdin=stdin,
                 stderr=subprocess.STDOUT,
                 quiet=True,
                 shell=shell,
@@ -363,6 +367,7 @@ def _run_quiet(cmd,
 
 def _run_all_quiet(cmd,
                    cwd=None,
+                   stdin=None,
                    runas=None,
                    shell=DEFAULT_SHELL,
                    env=(),
@@ -376,6 +381,7 @@ def _run_all_quiet(cmd,
     return _run(cmd,
                 runas=runas,
                 cwd=cwd,
+                stdin=stdin,
                 shell=shell,
                 env=env,
                 quiet=True,
@@ -386,6 +392,7 @@ def _run_all_quiet(cmd,
 
 def run(cmd,
         cwd=None,
+        stdin=None,
         runas=None,
         shell=DEFAULT_SHELL,
         env=(),
@@ -398,6 +405,9 @@ def run(cmd,
     '''
     Execute the passed command and return the output as a string
 
+    Note that ``env`` represents the environment variables for the command, and
+    should be formatted as a dict, or a YAML string which resolves to a dict.
+
     CLI Example::
 
         salt '*' cmd.run "ls -l | awk '/foo/{print \\$2}'"
@@ -408,11 +418,21 @@ def run(cmd,
 
         salt '*' cmd.run template=jinja "ls -l /tmp/{{grains.id}} | awk '/foo/{print \\$2}'"
 
+    Specify an alternate shell with the shell parameter::
+
+        salt '*' cmd.run "Get-ChildItem C:\\ " shell='powershell'
+
+    A string of standard input can be specified for the command to be run using
+    the ``stdin`` parameter. This can be useful in cases where sensitive
+    information must be read from standard input.::
+
+        salt '*' cmd.run "grep f" stdin='one\\ntwo\\nthree\\nfour\\nfive\\n'
     '''
     out = _run(cmd,
                runas=runas,
                shell=shell,
                cwd=cwd,
+               stdin=stdin,
                stderr=subprocess.STDOUT,
                env=env,
                template=template,
@@ -427,6 +447,7 @@ def run(cmd,
 
 def run_stdout(cmd,
                cwd=None,
+               stdin=None,
                runas=None,
                shell=DEFAULT_SHELL,
                env=(),
@@ -439,6 +460,9 @@ def run_stdout(cmd,
     '''
     Execute a command, and only return the standard out
 
+    Note that ``env`` represents the environment variables for the command, and
+    should be formatted as a dict, or a YAML string which resolves to a dict.
+
     CLI Example::
 
         salt '*' cmd.run_stdout "ls -l | awk '/foo/{print \\$2}'"
@@ -449,10 +473,16 @@ def run_stdout(cmd,
 
         salt '*' cmd.run_stdout template=jinja "ls -l /tmp/{{grains.id}} | awk '/foo/{print \\$2}'"
 
+    A string of standard input can be specified for the command to be run using
+    the ``stdin`` parameter. This can be useful in cases where sensitive
+    information must be read from standard input.::
+
+        salt '*' cmd.run_stdout "grep f" stdin='one\\ntwo\\nthree\\nfour\\nfive\\n'
     '''
     stdout = _run(cmd,
                   runas=runas,
                   cwd=cwd,
+                  stdin=stdin,
                   shell=shell,
                   env=env,
                   template=template,
@@ -467,6 +497,7 @@ def run_stdout(cmd,
 
 def run_stderr(cmd,
                cwd=None,
+               stdin=None,
                runas=None,
                shell=DEFAULT_SHELL,
                env=(),
@@ -479,6 +510,9 @@ def run_stderr(cmd,
     '''
     Execute a command and only return the standard error
 
+    Note that ``env`` represents the environment variables for the command, and
+    should be formatted as a dict, or a YAML string which resolves to a dict.
+
     CLI Example::
 
         salt '*' cmd.run_stderr "ls -l | awk '/foo/{print \\$2}'"
@@ -489,10 +523,16 @@ def run_stderr(cmd,
 
         salt '*' cmd.run_stderr template=jinja "ls -l /tmp/{{grains.id}} | awk '/foo/{print \\$2}'"
 
+    A string of standard input can be specified for the command to be run using
+    the ``stdin`` parameter. This can be useful in cases where sensitive
+    information must be read from standard input.::
+
+        salt '*' cmd.run_stderr "grep f" stdin='one\\ntwo\\nthree\\nfour\\nfive\\n'
     '''
     stderr = _run(cmd,
                   runas=runas,
                   cwd=cwd,
+                  stdin=stdin,
                   shell=shell,
                   env=env,
                   template=template,
@@ -507,6 +547,7 @@ def run_stderr(cmd,
 
 def run_all(cmd,
             cwd=None,
+            stdin=None,
             runas=None,
             shell=DEFAULT_SHELL,
             env=(),
@@ -519,6 +560,9 @@ def run_all(cmd,
     '''
     Execute the passed command and return a dict of return data
 
+    Note that ``env`` represents the environment variables for the command, and
+    should be formatted as a dict, or a YAML string which resolves to a dict.
+
     CLI Example::
 
         salt '*' cmd.run_all "ls -l | awk '/foo/{print \\$2}'"
@@ -529,10 +573,16 @@ def run_all(cmd,
 
         salt '*' cmd.run_all template=jinja "ls -l /tmp/{{grains.id}} | awk '/foo/{print \\$2}'"
 
+    A string of standard input can be specified for the command to be run using
+    the ``stdin`` parameter. This can be useful in cases where sensitive
+    information must be read from standard input.::
+
+        salt '*' cmd.run_all "grep f" stdin='one\\ntwo\\nthree\\nfour\\nfive\\n'
     '''
     ret = _run(cmd,
                runas=runas,
                cwd=cwd,
+               stdin=stdin,
                shell=shell,
                env=env,
                template=template,
@@ -562,6 +612,7 @@ def run_all(cmd,
 
 def retcode(cmd,
             cwd=None,
+            stdin=None,
             runas=None,
             shell=DEFAULT_SHELL,
             env=(),
@@ -572,6 +623,9 @@ def retcode(cmd,
     '''
     Execute a shell command and return the command's return code.
 
+    Note that ``env`` represents the environment variables for the command, and
+    should be formatted as a dict, or a YAML string which resolves to a dict.
+
     CLI Example::
 
         salt '*' cmd.retcode "file /bin/bash"
@@ -582,11 +636,17 @@ def retcode(cmd,
 
         salt '*' cmd.retcode template=jinja "file {{grains.pythonpath[0]}}/python"
 
+    A string of standard input can be specified for the command to be run using
+    the ``stdin`` parameter. This can be useful in cases where sensitive
+    information must be read from standard input.::
+
+        salt '*' cmd.retcode "grep f" stdin='one\\ntwo\\nthree\\nfour\\nfive\\n'
     '''
     return _run(
             cmd,
             runas=runas,
             cwd=cwd,
+            stdin=stdin,
             shell=shell,
             env=env,
             template=template,
@@ -599,6 +659,7 @@ def script(
         source,
         args=None,
         cwd=None,
+        stdin=None,
         runas=None,
         shell=DEFAULT_SHELL,
         env='base',
@@ -621,6 +682,13 @@ def script(
 
         salt '*' cmd.script salt://scripts/runme.sh
         salt '*' cmd.script salt://scripts/runme.sh 'arg1 arg2 "arg 3"'
+        salt '*' cmd.script salt://scripts/windows_task.ps1 args=' -Input c:\\tmp\\infile.txt' shell='powershell'
+
+    A string of standard input can be specified for the command to be run using
+    the ``stdin`` parameter. This can be useful in cases where sensitive
+    information must be read from standard input.::
+
+        salt '*' cmd.script salt://scripts/runme.sh stdin='one\\ntwo\\nthree\\nfour\\nfive\\n'
     '''
     if not salt.utils.is_windows():
         path = salt.utils.mkstemp(dir=cwd)
@@ -638,12 +706,12 @@ def script(
     ret = _run(
             path + ' ' + args if args else path,
             cwd=cwd,
+            stdin=stdin,
             quiet=kwargs.get('quiet', False),
             runas=runas,
             shell=shell,
             umask=umask,
-            timeout=timeout
-            )
+            timeout=timeout)
     os.remove(path)
     return ret
 
@@ -651,6 +719,7 @@ def script(
 def script_retcode(
         source,
         cwd=None,
+        stdin=None,
         runas=None,
         shell=DEFAULT_SHELL,
         env='base',
@@ -673,6 +742,12 @@ def script_retcode(
     CLI Example::
 
         salt '*' cmd.script_retcode salt://scripts/runme.sh
+
+    A string of standard input can be specified for the command to be run using
+    the ``stdin`` parameter. This can be useful in cases where sensitive
+    information must be read from standard input.::
+
+        salt '*' cmd.script_retcode salt://scripts/runme.sh stdin='one\\ntwo\\nthree\\nfour\\nfive\\n'
     '''
     return script(
             source,
