@@ -201,9 +201,10 @@ def add_host(ip, alias):
 def _write_hosts(hosts):
     lines = []
     for ip, aliases in hosts.iteritems():
-        lines.append(
-            '{0}\t\t{1}'.format(ip, '\t'.join(aliases))
-        )
+        for alias in aliases:
+            lines.append(
+                '{0}\t\t{1}'.format(ip, alias)
+            )
 
     hfn = __get_hosts_filename()
     with salt.utils.fopen(hfn, 'w+') as ofile:
