@@ -5,6 +5,9 @@ Module for managing keyboards on POSIX-like systems.
 # Import python libs
 import logging
 
+# Import salt libs
+import salt.utils
+
 log = logging.getLogger(__name__)
 
 
@@ -12,9 +15,7 @@ def __virtual__():
     '''
     Only work on POSIX-like systems
     '''
-    # Disable on these platforms
-    disable = ('Windows',)
-    if __grains__['os'] in disable:
+    if salt.utils.is_windows():
         return False
     return 'keyboard'
 
