@@ -132,9 +132,19 @@ def get(tgt, fun, expr_form='glob'):
     '''
     Get data from the mine based on the target, function and expr_form
 
+    Targets can be matched based on any standard matching system that can be
+    matched on the master via these keywords:
+
+        glob
+        pcre
+        grain
+        grain_pcre
+        pillar
+
     CLI Example::
 
         salt '*' mine.get '*' network.interfaces
+        salt '*' mine.get 'os:Fedora' network.interfaces grain
     '''
     auth = _auth()
     load = {
