@@ -2,6 +2,17 @@
 Module for gathering and managing information about MooseFS
 '''
 
+# Import salt libs
+import salt.utils
+
+def __virtual__():
+    '''
+    Only load if the mfs commands are installed
+    '''
+    if salt.utils.which('mfsgetgoal'):
+        return 'moosefs'
+    return False
+
 
 def dirinfo(path, opts=None):
     '''
