@@ -18,6 +18,10 @@ from salt.exceptions import CommandExecutionError, CommandNotFoundError
 
 logger = logging.getLogger(__name__)  # pylint: disable-msg=C0103
 
+# Don't shadow built-in's.
+__func_alias__ = {
+    'list_': 'list'
+}
 
 VALID_PROTOS = ['http', 'https', 'ftp']
 
@@ -35,7 +39,10 @@ def _get_pip_bin(bin_env):
 
     # try to get pip bin from env
     if os.path.isdir(bin_env):
-        pip_bin = os.path.join(bin_env, 'bin', 'pip')
+        if salt.utils.is_windows():
+            pip_bin = os.path.join(bin_env, 'Scripts', 'pip.exe')
+        else:
+            pip_bin = os.path.join(bin_env, 'bin', 'pip')
         if os.path.isfile(pip_bin):
             return pip_bin
         raise CommandNotFoundError('Could not find a `pip` binary')
@@ -43,6 +50,39 @@ def _get_pip_bin(bin_env):
     return bin_env
 
 
+def _get_cached_requirements(requirements):
+    """Get the location of a cached requirements file; caching if necessary."""
+    cached_requirements = __salt__['cp.is_cached'](
+        requirements, __env__
+    )
+    if not cached_requirements:
+        # It's not cached, let's cache it.
+        cached_requirements = __salt__['cp.cache_file'](
+            requirements, __env__
+        )
+    # Check if the master version has changed.
+    if __salt__['cp.hash_file'](requirements, __env__) != \
+            __salt__['cp.hash_file'](cached_requirements, __env__):
+        cached_requirements = __salt__['cp.cache_file'](
+            requirements, __env__
+        )
+
+    return cached_requirements
+
+
+def _get_env_activate(bin_env):
+    if not bin_env:
+        raise CommandNotFoundError('Could not find a `activate` binary')
+
+    if os.path.isdir(bin_env):
+        if salt.utils.is_windows():
+            pip_bin = os.path.join(bin_env, 'Scripts', 'activate.bat')
+        else:
+            activate_bin = os.path.join(bin_env, 'bin', 'activate')
+        if os.path.isfile(activate_bin):
+            return activate_bin
+    raise CommandNotFoundError('Could not find a `activate` binary')
+
 def install(pkgs=None,
             requirements=None,
             env=None,
@@ -64,6 +104,7 @@ def install(pkgs=None,
             upgrade=False,
             force_reinstall=False,
             ignore_installed=False,
+            exists_action=None,
             no_deps=False,
             no_install=False,
             no_download=False,
@@ -71,6 +112,7 @@ def install(pkgs=None,
             runas=None,
             no_chown=False,
             cwd=None,
+            activate=False,
             __env__='base'):
     '''
     Install packages with pip
@@ -131,6 +173,8 @@ def install(pkgs=None,
         up-to-date.
     ignore_installed
         Ignore the installed packages (reinstalling instead)
+    exists_action
+        Default action when a path already exists: (s)witch, (i)gnore, (w)wipe, (b)ackup
     no_deps
         Ignore package dependencies
     no_install
@@ -153,6 +197,9 @@ def install(pkgs=None,
         a requirements file
     cwd
         Current working directory to run pip from
+    activate
+        Activates the virtual environment, if given via bin_env,
+        before running install.
 
 
     CLI Example::
@@ -181,6 +228,13 @@ def install(pkgs=None,
 
     cmd = '{0} install'.format(_get_pip_bin(bin_env))
 
+    if activate and bin_env:
+        if salt.utils.is_windows():
+            source_cmd = ''
+        else:
+            source_cmd = '. '
+        cmd = '{0}{1} && {2}'.format(source_cmd, _get_env_activate(bin_env), cmd)
+
     if pkgs:
         pkg = pkgs.replace(',', ' ')
         # It's possible we replaced version-range commas with semicolons so
@@ -193,20 +247,7 @@ def install(pkgs=None,
     treq = None
     if requirements:
         if requirements.startswith('salt://'):
-            cached_requirements = __salt__['cp.is_cached'](
-                requirements, __env__
-            )
-            if not cached_requirements:
-                # It's not cached, let's cache it.
-                cached_requirements = __salt__['cp.cache_file'](
-                    requirements, __env__
-                )
-            # Check if the master version has changed.
-            if __salt__['cp.hash_file'](requirements, __env__) != \
-                    __salt__['cp.hash_file'](cached_requirements, __env__):
-                cached_requirements = __salt__['cp.cache_file'](
-                    requirements, __env__
-                )
+            cached_requirements = _get_cached_requirements(requirements)
             if not cached_requirements:
                 return {
                     'result': False,
@@ -216,7 +257,6 @@ def install(pkgs=None,
                         )
                     )
                 }
-
             requirements = cached_requirements
 
         if runas and not no_chown:
@@ -328,6 +368,10 @@ def install(pkgs=None,
     if ignore_installed:
         cmd = '{cmd} --ignore-installed '.format(cmd=cmd)
 
+    if exists_action:
+        cmd = '{cmd} --exists-action={action} '.format(
+            cmd=cmd, action=exists_action)
+
     if no_deps:
         cmd = '{cmd} --no-deps '.format(cmd=cmd)
 
@@ -485,15 +529,7 @@ def freeze(bin_env=None,
 
     pip_bin = _get_pip_bin(bin_env)
 
-    activate = os.path.join(os.path.dirname(pip_bin), 'activate')
-    if not os.path.isfile(activate):
-        raise CommandExecutionError(
-            "Could not find the path to the virtualenv's 'activate' binary"
-        )
-
-    # We use dot(.) instead of source because it's apparently the better and/or
-    # more supported way to source files on the various "major" Linux shells.
-    cmd = '. {0}; {1} freeze'.format(activate, pip_bin)
+    cmd = '{0} freeze'.format(_get_pip_bin(bin_env))
 
     result = __salt__['cmd.run_all'](cmd, runas=runas, cwd=cwd)
 
@@ -503,7 +539,7 @@ def freeze(bin_env=None,
     return result['stdout'].splitlines()
 
 
-def list(prefix='',
+def list_(prefix='',
          bin_env=None,
          runas=None,
          cwd=None):
@@ -526,15 +562,14 @@ def list(prefix='',
     for line in result['stdout'].splitlines():
         if line.startswith('-e'):
             line = line.split('-e ')[1]
-            line, name = line.split('#egg=')
-            packages[name] = line
-
+            version, name = line.split('#egg=')
         elif len(line.split('==')) >= 2:
             name = line.split('==')[0]
             version = line.split('==')[1]
-            if prefix:
-                if line.lower().startswith(prefix.lower()):
-                    packages[name] = version
-            else:
+
+        if prefix:
+            if name.lower().startswith(prefix.lower()):
                 packages[name] = version
+        else:
+            packages[name] = version
     return packages
