@@ -75,6 +75,15 @@ def _error_msg_iface(iface, option, expected):
     return msg.format(iface, option, '|'.join(expected))
 
 
+def _error_msg_routes(iface, option, expected):
+    '''
+    Build an appropriate error message from a given option and
+    a list of expected values.
+    '''
+    msg = 'Invalid option -- Route interface: {0}, Option: {1}, Expected: [{2}]'
+    return msg.format(iface, option, expected)
+
+
 def _log_default_iface(iface, opt, value):
     msg = 'Using default option -- Interface: {0} Option: {1} Value: {2}'
     log.info(msg.format(iface, opt, value))
@@ -637,6 +646,23 @@ def _parse_settings_eth(opts, iface_type, enabled, iface):
     return result
 
 
+def _parse_routes(iface, opts):
+    '''
+    Filters given options and outputs valid settings for
+    the route settings file.
+    '''
+    # Normalize keys
+    opts = dict((k.lower(), v) for (k, v) in opts.iteritems())
+    result = {}
+    if not 'routes' in opts:
+        _raise_error_routes(iface, 'routes', 'List of routes')
+
+    for opt in opts:
+        result[opt] = opts[opt]
+
+    return result
+
+
 def _parse_network_settings(opts, current):
     '''
     Filters given options and outputs valid settings for
@@ -708,6 +734,15 @@ def _raise_error_network(option, expected):
     raise AttributeError(msg)
 
 
+def _raise_error_routes(iface, option, expected):
+    '''
+    Log and raise an error with a logical formated message.
+    '''
+    msg = _error_msg_routes(iface, option, expected)
+    log.error(msg)
+    raise AttributeError(msg)
+
+
 def _read_file(path):
     '''
     Reads and returns the contents of a file
@@ -752,7 +787,7 @@ def _read_temp(data):
     return output
 
 
-def build_bond(iface, settings):
+def build_bond(iface, **settings):
     '''
     Create a bond script in /etc/modprobe.d with the passed settings
     and load the bonding kernel module.
@@ -788,7 +823,7 @@ def build_bond(iface, settings):
     return _read_file(path)
 
 
-def build_interface(iface, iface_type, enabled, settings):
+def build_interface(iface, iface_type, enabled, **settings):
     '''
     Build an interface script for a network interface.
 
@@ -842,7 +877,36 @@ def build_interface(iface, iface_type, enabled, settings):
     return _read_file(path)
 
 
-def down(iface, iface_type, opts):
+def build_routes(iface, **settings):
+    '''
+    Build an route script for a network interface.
+
+    CLI Example::
+
+        salt '*' ip.build_routes eth0 <settings>
+    '''
+
+    iface = iface.lower()
+    opts = _parse_routes(iface, settings)
+    try:
+        template = ENV.get_template('route_eth.jinja')
+    except jinja2.exceptions.TemplateNotFound:
+        log.error(
+            'Could not load template route_eth.jinja'
+        )
+        return ''
+    routecfg = template.render(routes=opts['routes'])
+
+    if settings['test']:
+        return _read_temp(routecfg)
+
+    _write_file_iface(iface, routecfg, _RH_NETWORK_SCRIPT_DIR, 'route-{0}')
+    path = os.path.join(_RH_NETWORK_SCRIPT_DIR, 'route-{0}'.format(iface))
+
+    return _read_file(path)
+
+
+def down(iface, iface_type):
     '''
     Shutdown a network interface
 
@@ -880,7 +944,7 @@ def get_interface(iface):
     return _read_file(path)
 
 
-def up(iface, iface_type, opts):  # pylint: disable-msg=C0103
+def up(iface, iface_type):  # pylint: disable-msg=C0103
     '''
     Start up a network interface
 
@@ -894,6 +958,18 @@ def up(iface, iface_type, opts):  # pylint: disable-msg=C0103
     return None
 
 
+def get_routes(iface):
+    '''
+    Return the contents of the interface routes script.
+
+    CLI Example::
+
+        salt '*' ip.get_routes eth0
+    '''
+    path = os.path.join(_RH_NETWORK_SCRIPT_DIR, 'route-{0}'.format(iface))
+    return _read_file(path)
+
+
 def get_network_settings():
     '''
     Return the contents of the global network script.
@@ -905,7 +981,7 @@ def get_network_settings():
     return _read_file(_RH_NETWORK_FILE)
 
 
-def apply_network_settings(opts):
+def apply_network_settings(**settings):
     '''
     Apply global network configuration.
 
@@ -913,10 +989,10 @@ def apply_network_settings(opts):
 
         salt '*' ip.apply_network_settings
     '''
-    if not 'require_reboot' in opts:
-        opts['require_reboot'] = False
+    if not 'require_reboot' in settings:
+        settings['require_reboot'] = False
 
-    if opts['require_reboot'] in _CONFIG_TRUE:
+    if settings['require_reboot'] in _CONFIG_TRUE:
         log.warning(
             'The network state sls is requiring a reboot of the system to '
             'properly apply network configuration.'
@@ -926,7 +1002,7 @@ def apply_network_settings(opts):
         return __salt__['service.restart']('network')
 
 
-def build_network_settings(settings):
+def build_network_settings(**settings):
     '''
     Build the global network script.
 
@@ -953,3 +1029,4 @@ def build_network_settings(settings):
     _write_file_network(network, _RH_NETWORK_FILE)
 
     return _read_file(_RH_NETWORK_FILE)
+
