@@ -185,7 +185,7 @@ def highstate(test=None, **kwargs):
     if salt.utils.test_mode(test=test, **kwargs):
         opts['test'] = True
     else:
-        opts['test'] = None
+        opts['test'] = __opts__.get('test', None)
 
     if 'env' in kwargs:
         opts['environment'] = kwargs['env']
@@ -244,7 +244,7 @@ def sls(mods, env='base', test=None, exclude=None, **kwargs):
     if salt.utils.test_mode(test=test, **kwargs):
         opts['test'] = True
     else:
-        opts['test'] = None
+        opts['test'] = __opts__.get('test', None)
 
     pillar = kwargs.get('pillar')
 
@@ -322,7 +322,7 @@ def top(topfn, test=None, **kwargs):
     if salt.utils.test_mode(test=test, **kwargs):
         __opts__['test'] = True
     else:
-        __opts__['test'] = None
+        __opts__['test'] = __opts__.get('test', None)
     st_ = salt.state.HighState(__opts__)
     st_.push_active()
     st_.opts['state_top'] = os.path.join('salt://', topfn)
@@ -381,7 +381,7 @@ def show_sls(mods, env='base', test=None, **kwargs):
     if salt.utils.test_mode(test=test, **kwargs):
         opts['test'] = True
     else:
-        opts['test'] = None
+        opts['test'] = __opts__.get('test', None)
     st_ = salt.state.HighState(opts)
     if isinstance(mods, string_types):
         mods = mods.split(',')
@@ -461,7 +461,7 @@ def single(fun, name, test=None, **kwargs):
     if salt.utils.test_mode(test=test, **kwargs):
         opts['test'] = True
     else:
-        opts['test'] = None
+        opts['test'] = __opts__.get('test', None)
     st_ = salt.state.State(opts)
     err = st_.verify_data(kwargs)
     if err:
