@@ -20,7 +20,7 @@ def __virtual__():
     return 'sys'
 
 
-def doc(module=''):
+def doc(*args, **kwargs):
     '''
     Return the docstrings for all modules. Optionally, specify a module or a
     function to narrow the selection.
@@ -28,43 +28,63 @@ def doc(module=''):
     The strings are aggregated into a single document on the master for easy
     reading.
 
+    Multiple modules/functions can be specified.
+
     CLI Example::
 
         salt '*' sys.doc
         salt '*' sys.doc sys
         salt '*' sys.doc sys.doc
+        salt '*' sys.doc network.traceroute user.info
     '''
+    ### NOTE: **kwargs is used here to prevent a traceback when garbage
+    ###       arguments are tacked on to the end.
     docs = {}
-    if module:
-        # allow both "sys" and "sys." to match sys, without also matching
-        # sysctl
-        target_mod = module + '.' if not module.endswith('.') else module
-    else:
-        target_mod = ''
-    for fun in __salt__:
-        if fun == module or fun.startswith(target_mod):
+    if not args:
+        for fun in __salt__:
             docs[fun] = __salt__[fun].__doc__
+        return docs
+
+    for module in args:
+        if module:
+            # allow both "sys" and "sys." to match sys, without also matching
+            # sysctl
+            target_mod = module + '.' if not module.endswith('.') else module
+        else:
+            target_mod = ''
+        for fun in __salt__:
+            if fun == module or fun.startswith(target_mod):
+                docs[fun] = __salt__[fun].__doc__
     return docs
 
 
-def list_functions(module=''):
+def list_functions(*args, **kwargs):
     '''
-    List the functions for all modules. Optionally, specify a module to list
-    from.
+    List the functions for all modules. Optionally, specify a module or modules
+    from which to list.
 
     CLI Example::
 
         salt '*' sys.list_functions
         salt '*' sys.list_functions sys
+        salt '*' sys.list_functions sys user
     '''
+    ### NOTE: **kwargs is used here to prevent a traceback when garbage
+    ###       arguments are tacked on to the end.
+
+    if not args:
+        # We're being asked for all functions
+        return sorted(__salt__)
+
     names = set()
-    if module:
-        # allow both "sys" and "sys." to match sys, without also matching
-        # sysctl
-        module = module + '.' if not module.endswith('.') else module
-    for func in __salt__:
-        if func.startswith(module):
-            names.add(func)
+    for module in args:
+        if module:
+            # allow both "sys" and "sys." to match sys, without also matching
+            # sysctl
+            module = module + '.' if not module.endswith('.') else module
+        for func in __salt__:
+            if func.startswith(module):
+                names.add(func)
     return sorted(names)
 
 
@@ -97,6 +117,7 @@ def reload_modules():
     # it ever gets here
     return True
 
+
 def argspec(module=''):
     '''
     Return the argument specification of functions in Salt execution
